use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::NoTabs 0.15

use Test::More 0.88;
use Test::NoTabs;

my @files = (
    'lib/MooseX/MethodAttributes.pm',
    'lib/MooseX/MethodAttributes/Inheritable.pm',
    'lib/MooseX/MethodAttributes/Role.pm',
    'lib/MooseX/MethodAttributes/Role/AttrContainer.pm',
    'lib/MooseX/MethodAttributes/Role/AttrContainer/Inheritable.pm',
    'lib/MooseX/MethodAttributes/Role/Meta/Class.pm',
    'lib/MooseX/MethodAttributes/Role/Meta/Map.pm',
    'lib/MooseX/MethodAttributes/Role/Meta/Method.pm',
    'lib/MooseX/MethodAttributes/Role/Meta/Method/MaybeWrapped.pm',
    'lib/MooseX/MethodAttributes/Role/Meta/Method/Wrapped.pm',
    'lib/MooseX/MethodAttributes/Role/Meta/Role.pm',
    'lib/MooseX/MethodAttributes/Role/Meta/Role/Application.pm',
    'lib/MooseX/MethodAttributes/Role/Meta/Role/Application/Summation.pm',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/basic.t',
    't/calling.t',
    't/catalyst.t',
    't/catalyst_role.t',
    't/catalyst_role_method_exclusion.t',
    't/catalyst_role_preexist_methods.t',
    't/inherited.t',
    't/inherited_non_moose_multilevel.t',
    't/late_reinitialize.t',
    't/lib/BaseClass.pm',
    't/lib/CatalystLike/Controller.pm',
    't/lib/CatalystLike/Controller/Moose.pm',
    't/lib/CatalystLike/Controller/Moose/MethodModifiers.pm',
    't/lib/ClassUsingRoleWithAttributes.pm',
    't/lib/OtherRoleWithAttributes.pm',
    't/lib/OtherSubClass.pm',
    't/lib/RoleWithAttributes.pm',
    't/lib/SubClass.pm',
    't/lib/SubClassUseBaseAndUseMoose.pm',
    't/lib/SubSubClass.pm',
    't/lib/TestClass.pm',
    't/lib/UsesMultipleRoles.pm',
    't/multiple_roles.t',
    't/multiple_roles_astrait.t',
    't/override_method_with_no_attribute.t',
    't/param_role.t',
    't/role.t',
    't/role_applied.t',
    't/role_comp.t',
    't/role_in_role.t',
    't/role_in_role_more.t',
    't/role_method_conflict_detection.t',
    't/role_with_anon_class.t',
    't/zzz-check-breaks.t',
    'xt/author/00-compile.t',
    'xt/author/clean-namespaces.t',
    'xt/author/eol.t',
    'xt/author/kwalitee.t',
    'xt/author/mojibake.t',
    'xt/author/no-tabs.t',
    'xt/author/pod-spell.t',
    'xt/release/changes_has_content.t',
    'xt/release/cpan-changes.t',
    'xt/release/distmeta.t',
    'xt/release/minimum-version.t',
    'xt/release/pod-coverage.t',
    'xt/release/pod-no404s.t',
    'xt/release/pod-syntax.t',
    'xt/release/portability.t'
);

notabs_ok($_) foreach @files;
done_testing;
