use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006009
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
irc
metamethod
metarole
initialisation
Florian
Ragwitz
rafl
Tomas
Doran
bobtfish
Karen
Etheridge
ether
Dave
Rolsky
autarch
Marcus
Ramberg
marcus
Peter
Karman
pek
David
Steinbrunner
dsteinbrunner
lib
MooseX
MethodAttributes
Inheritable
Role
AttrContainer
Meta
Class
Map
Method
MaybeWrapped
Wrapped
Application
Summation
